from setuptools import setup, find_packages

VERSION = '1.0.0'
DESCRIPTION = "kekw package"
LONG_DESCRIPTION = "kekw package"

# Setting up
setup(
    name="sekuhsgehkuljsgehljkesglhku",
    version=VERSION,
    author="StarlessGem",
    author_email="StarlessGem@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python'],
    classifiers=[
        "Operating System :: Microsoft :: Windows",
    ]
)